"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// note that we are using @heroku-cli/command instead of @oclif/command
// this inherits from @oclif/command but extends it with Heroku-specific functionality
const command_1 = require("@heroku-cli/command");
const TasksHeaders = {
    'Accept': 'application/vnd.api+json',
    'Content-Type': 'application/vnd.api+json'
};
class AppCommand extends command_1.Command {
    async run() {
        const { flags } = this.parse(AppCommand);
        const response = await this.heroku.get(`/apps/${flags.app}`);
        const app = response.body;
        const appId = app.id;
        const url = `https://tasks.heroku.com/apps/${appId}/migrate`;
        let getRequestResponse;
        try {
            getRequestResponse = await this.heroku.get(url, { headers: TasksHeaders });
        }
        catch (err) {
            if (err.statusCode === 404) {
                // situation 1: they don't have the scheduler add-on at all
                // situation 2: they have scheduler but no jobs exist
                this.warn('There are no jobs to migrate from Scheduler.');
                return;
            }
            throw err;
        }
        let postRequestResponse;
        try {
            postRequestResponse = await this.heroku.post(url, {
                headers: TasksHeaders,
                body: JSON.stringify(getRequestResponse.body)
            });
        }
        catch (err) {
            if (err.statusCode === 400) {
                // situation 3: they have scheduler, and jobs exist, but have all been added already
                this.warn('All existing Scheduler jobs have already been migrated.');
                return;
            }
            throw err;
        }
        const jobsAdded = postRequestResponse.body.data.length;
        const noun = jobsAdded > 1 ? 'jobs' : 'job';
        this.log(`You have successfully migrated ${jobsAdded} ${noun} from the Heroku Scheduler add-on into Heroku Automations.`);
    }
}
AppCommand.description = 'Import existing jobs from the Heroku Scheduler add-on into Heroku Automations';
AppCommand.flags = {
    remote: command_1.flags.remote(),
    app: command_1.flags.app({ required: true })
};
exports.default = AppCommand;
